@@ -1,4 +1,5 @@
 #
+# Copyright (c) 2005 Canonical
 # Copyright (c) 2004 Conectiva, Inc.
 #
 # Written by Gustavo Niemeyer <niemeyer@conectiva.com>
@@ -78,8 +79,8 @@ class DebPackage(Package):
         for nameversion, cutoff in searcher.nameversion:
             _, ratio1 = globdistance(nameversion, myname, cutoff, ic)
             _, ratio2 = globdistance(nameversion,
-                                     "%s-%s" % (myname, myversion), cutoff, ic)
-            _, ratio3 = globdistance(nameversion, "%s-%s" %
+                                     "%s_%s" % (myname, myversion), cutoff, ic)
+            _, ratio3 = globdistance(nameversion, "%s_%s" %
                                      (myname, splitrelease(myversion)[0]),
                                      cutoff, ic)
             ratio = max(ratio, ratio1, ratio2, ratio3)
@@ -93,6 +94,9 @@ class DebPackage(Package):
                 rc = vercmp(self.version, other.version)
         return rc == -1
 
+    def __str__(self):
+        return "%s_%s" % (self.name, self.version)
+
 class DebProvides(Provides):        __slots__ = ()
 class DebNameProvides(DebProvides): __slots__ = ()
 
