@@ -100,14 +100,17 @@ class RPMHeaderPackageInfo(PackageInfo):
 
     def getSummary(self):
         s = self._h[rpm.RPMTAG_SUMMARY]
-        for encoding in ENCODINGS:
-            try:
-                s = s.decode(encoding)
-            except UnicodeDecodeError:
-                continue
-            break
-        else:
+        if not s:
             s = ""
+        else:
+            for encoding in ENCODINGS:
+                try:
+                    s = s.decode(encoding)
+                except UnicodeDecodeError:
+                    continue
+                break
+            else:
+                s = ""
         return s
 
     def getGroup(self):
@@ -232,7 +235,9 @@ class RPMHeaderLoader(Loader):
             if n:
                 f = h[1048] # RPMTAG_REQUIREFLAGS
                 v = h[1050] # RPMTAG_REQUIREVERSION
-                if type(f) != list:
+                if f == None:
+                    f = [0]
+                elif type(f) != list:
                     f = [f]
                 reqdict = {}
                 for i in range(len(n)):
@@ -259,16 +264,16 @@ class RPMHeaderLoader(Loader):
             if n:
                 f = h[1053] # RPMTAG_CONFLICTFLAGS
                 v = h[1055] # RPMTAG_CONFLICTVERSION
+                if f == None:
+                    f = [0]
+                elif type(f) != list:
+                    f = [f]
                 cnfargs = []
                 for i in range(len(n)):
                     vi = v[i] or None
                     if vi and vi[:2] == "0:":
                         vi = vi[2:]
-                    if i == 0 and type(f) != list:
-                        fi = f
-                    else:
-                        fi = f[i]
-                    cnfargs.append((Cnf, n[i], CM.get(fi&CF), vi))
+                    cnfargs.append((Cnf, n[i], CM.get(f[i]&CF), vi))
             else:
                 cnfargs = []
 
@@ -278,16 +283,20 @@ class RPMHeaderLoader(Loader):
             if n:
                 f = h[1114] # RPMTAG_OBSOLETEFLAGS
                 v = h[1115] # RPMTAG_OBSOLETEVERSION
+                if f == None:
+                    f = [0]
+                elif type(f) != list:
+                    f = [f]
                 upgargs = []
                 for i in range(len(n)):
-                    vi = v[i] or None
+                    try:
+                        vi = v[i] or None
+                    except TypeError:
+                        vi = None
+                        pass
                     if vi and vi[:2] == "0:":
                         vi = vi[2:]
-                    if i == 0 and type(f) != list:
-                        fi = f
-                    else:
-                        fi = f[i]
-                    upgargs.append((Obs, n[i], CM.get(fi&CF), vi))
+                    upgargs.append((Obs, n[i], CM.get(f[i]&CF), vi))
                 cnfargs.extend(upgargs)
                 upgargs.append(obstup)
             else:
