@@ -21,8 +21,8 @@
 #
 from smart.transaction import Transaction, PolicyInstall, sortUpgrades
 from smart.transaction import INSTALL, REINSTALL
-from smart.matcher import MasterMatcher
 from smart.option import OptionParser
+from smart.cache import Package
 from smart import *
 import string
 import re
@@ -56,6 +56,9 @@ def parse_options(argv):
                       help=_("dump needed urls and don't commit operation"))
     parser.add_option("--download", action="store_true",
                       help=_("download packages and don't commit operation"))
+    parser.add_option("--explain", action="store_true",
+                      help=_("include additional information about changes,"
+                             "when possible"))
     parser.add_option("-y", "--yes", action="store_true",
                       help=_("do not ask for confirmation"))
     opts, args = parser.parse_args(argv)
@@ -64,6 +67,9 @@ def parse_options(argv):
 
 def main(ctrl, opts):
 
+    if opts.explain:
+        sysconf.set("explain-changesets", True, soft=True)
+
     urls = []
     for arg in opts.args[:]:
         if (os.path.isfile(arg) and
@@ -91,13 +97,57 @@ def main(ctrl, opts):
                 if pkg.installed:
                     raise Error, _("%s is already installed") % pkg
                 trans.enqueue(pkg, INSTALL)
+
+
     for arg in opts.args:
-        matcher = MasterMatcher(arg)
-        pkgs = matcher.filter(cache.getPackages())
+
+        ratio, results, suggestions = ctrl.search(arg)
+
+        if not results:
+            if suggestions:
+                dct = {}
+                for r, obj in suggestions:
+                    if isinstance(obj, Package):
+                        dct[obj] = True
+                    else:
+                        dct.update(dict.fromkeys(obj.packages, True))
+                raise Error, _("'%s' matches no packages. "
+                               "Suggestions:\n%s") % \
+                             (arg, "\n".join(["    "+str(x) for x in dct]))
+            else:
+                raise Error, _("'%s' matches no packages") % arg
+
+        pkgs = []
+
+        for obj in results:
+            if isinstance(obj, Package):
+                pkgs.append(obj)
+
         if not pkgs:
-            raise Error, _("'%s' matches no packages") % arg
+            installed = False
+            names = {}
+            for obj in results:
+                for pkg in obj.packages:
+                    if pkg.installed:
+                        iface.warning(_("%s (for %s) is already installed")
+                                      % (pkg, arg))
+                        installed = True
+                        break
+                    else:
+                        pkgs.append(pkg)
+                        names[pkg.name] = True
+                else:
+                    continue
+                break
+            if installed:
+                continue
+            if len(names) > 1:
+                raise Error, _("There are multiple matches for '%s':\n%s") % \
+                              (arg, "\n".join(["    "+str(x) for x in pkgs]))
+
         if len(pkgs) > 1:
             sortUpgrades(pkgs)
+
         names = {}
         for pkg in pkgs:
             names.setdefault(pkg.name, []).append(pkg)
@@ -107,6 +157,7 @@ def main(ctrl, opts):
                 iface.warning(_("%s is already installed") % pkg)
             else:
                 trans.enqueue(pkg, INSTALL)
+
     iface.showStatus(_("Computing transaction..."))
     trans.run()
     iface.hideStatus()
